#
# spec file for package javapackages-tools
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "extras"
%bcond_without python
%else
%bcond_with python
%endif
%if %{with python}
Name:           javapackages-tools-%{flavor}
%else
Name:           javapackages-tools
%endif
Version:        5.3.0
Release:        1.36
Summary:        Macros and scripts for Java packaging support
License:        BSD-3-Clause
Group:          Development/Languages/Java
URL:            https://github.com/fedora-java/javapackages
Source0:        https://github.com/fedora-java/javapackages/archive/%{version}.tar.gz
#PATCH-FIX-SUSE: SUSE does store jvm related things in libdir - ie /usr/lib64 on 64bits
#                where Fedora use jpackage convention - usr/lib everywhere
Patch0:         suse-use-libdir.patch
#PATCH-FIX-SUSE: allow building without python to reduce depgraph
Patch1:         python-optional.patch
#PATCH-FIX-SUSE: SUSE did not bump epoch of openjdk packages, whereas Fedora did
#               Avoid generating unresolvable requires
Patch2:         suse-no-epoch.patch
BuildRequires:  asciidoc
BuildRequires:  fdupes
BuildRequires:  perl
BuildRequires:  rpm
BuildRequires:  xmlto
Requires:       javapackages-filesystem = %{version}-%{release}
# Used on too many places
Provides:       jpackage-utils = %{version}
Obsoletes:      %{name}-doc
Obsoletes:      jpackage-utils < %{version}
%if %{with python}
BuildRequires:  python3-lxml
BuildRequires:  python3-nose
BuildRequires:  python3-setuptools
BuildRequires:  python3-six
BuildArch:      noarch
%else
Provides:       mvn(com.sun:tools) = SYSTEM
Provides:       mvn(sun.jdk:jconsole) = SYSTEM
%endif

%description
This package provides macros and scripts to support Java packaging.

%package -n javapackages-filesystem
Summary:        Java packages filesystem layout
Group:          Development/Languages/Java

%description -n javapackages-filesystem
This package provides some basic directories into which Java packages
install their content.

%if %{with python}
%package -n javapackages-gradle
Summary:        Local mode for Gradle (files)
Group:          Development/Languages/Java
Requires:       javapackages-local = %{version}
Requires:       javapackages-tools = %{version}

%description -n javapackages-gradle
This package contains files needed by local mode for Gradle, which
allows artifact resolution using XMvn resolver.


%package -n javapackages-ivy
Summary:        Local mode for Apache Ivy (files)
Group:          Development/Languages/Java
Requires:       javapackages-local = %{version}
Requires:       javapackages-tools = %{version}

%description -n javapackages-ivy
This package contains files needed by local mode fow Apache Ivy, which
allows artifact resolution using XMvn resolver.

%package -n python3-javapackages
Summary:        Module for handling various files for Java packaging
Group:          Development/Languages/Java
Requires:       python3-lxml
Requires:       python3-six
Obsoletes:      python-javapackages < %{version}-%{release}
Provides:       python-javapackages = %{version}-%{release}

%description -n python3-javapackages
Module for handling, querying and manipulating of various files for Java
packaging in Linux distributions

%package -n javapackages-local
Summary:        Non-essential macros and scripts for Java packaging support
Group:          Development/Languages/Java
Requires:       java-devel
Requires:       javapackages-tools = %{version}
Requires:       python3-javapackages = %{version}

%description -n javapackages-local
This package provides non-essential macros and scripts to support Java packaging.
%endif

%prep
%setup -q -n javapackages-%{version}
%autopatch -p1

# The usr/lib is hardcoded in configuration files too
new_dir=$(echo %{_libdir} | sed 's#/##')
perl -pi -e "s#usr/lib#${new_dir}#g" configs/*.xml

%build
%configure \
%if %{with python}
    --pyinterpreter=%{_bindir}/python3
%else
    --pyinterpreter=%{nil}
%endif
./build
%if %{with python}
pushd python
python3 setup.py build
popd
%endif

%install
./install
sed -e 's/.[17]$/&.gz/' -e 's/.py$/&*/' -i files-*

%if %{with python}
pushd python
python3 setup.py install --root %{buildroot}
popd
# kill all the common files
files="
%{_bindir}/build-classpath
%{_bindir}/build-classpath-directory
%{_bindir}/build-jar-repository
%{_bindir}/check-binary-files
%{_bindir}/clean-binary-files
%{_bindir}/create-jar-links
%{_bindir}/diff-jars
%{_bindir}/find-jar
%{_bindir}/rebuild-jar-repository
%{_bindir}/shade-jar
%{_sysconfdir}/java/font.properties
%{_sysconfdir}/java/java.conf
%{_sysconfdir}/java/eclipse.conf
%{_datadir}/java-utils/java-functions
%{_datadir}/java-utils/java-wrapper
%{_datadir}/java-utils/scl-enable
%{_libexecdir}/rpm/macros.d/macros.jpackage
%{_libexecdir}/rpm/macros.d/macros.javapackages-filesystem
%{_mandir}/man1/build-classpath.1
%{_mandir}/man1/build-jar-repository.1
%{_mandir}/man1/diff-jars.1
%{_mandir}/man1/rebuild-jar-repository.1
%{_mandir}/man1/shade-jar.1
%{_mandir}/man1/find-jar.1
%{_datadir}/maven-metadata/javapackages-metadata.xml
%{_datadir}/xmvn/configuration.xml
"
for i in $files; do
    rm -rf %{buildroot}/$i
done
%endif

rm -rf %{buildroot}%{_datadir}/fedora-review/

%fdupes %{buildroot}/%{_prefix}

%check
./check

%if !%{with python}
%files -f files-tools
%license LICENSE

%files -n javapackages-filesystem -f files-filesystem

%else
%files -n javapackages-local -f files-local
%dir %{_datadir}/java-utils

%files -n javapackages-gradle -f files-gradle
%dir %{_datadir}/gradle-local

%files -n javapackages-ivy -f files-ivy
%dir %{_sysconfdir}/ant.d

%files -n python3-javapackages
%license LICENSE
%{python3_sitelib}/javapackages*
%endif

%changelog
* Sat Apr  6 2019 fstrba@suse.com
- Rename gradle-local and ivy-local to javapackages-gradle and
  javapackages-ivy and let them depend only on javapackages-tools
  and javapackages-local. These packages only install files
  produced during the javapackages-tools build. The dependencies
  will be pulled by gradle-local, ivy-local and maven-local
  meta-packages built in a separate spec file.
* Thu Apr  4 2019 fstrba@suse.com
- Split maven-local meta-package out of javapackages-tools spec
  file
* Wed Apr  3 2019 fstrba@suse.com
- Make the ivy-local and maven-local sub-packages depend on the
  right stuff, so that they actually can be used for building
* Mon Mar  4 2019 fstrba@suse.com
- Provide both com.sun:tools and sun.jdk:jconsole that are part of
  standard OpenJDK installation. These provides cannot be generated
  from metadata due to build sequence.
* Tue Nov 27 2018 fstrba@suse.com
- Modified patch:
  * suse-use-libdir.patch
    + fix directories for eclipse.conf too
* Sun Nov 11 2018 fstrba@suse.com
- Make the javapackages-local package depend on java-devel. It is
  used for package building and this avoids each package to require
  java-devel itself.
* Mon Nov  5 2018 fstrba@suse.com
- Replace the occurences of /usr/lib by libdir in configuration
  files too
* Wed Oct 24 2018 fstrba@suse.com
- Update to version 5.3.0
- Modified patch:
  * suse-no-epoch.patch
    + rediff to changed code
- Build the :extras flavour as noarch
* Wed Oct 24 2018 fstrba@suse.com
- Added patch:
  * suse-no-epoch.patch
    + we did not bump epoch of OpenJDK packages in SUSE
    + fix a potential generation of unresolvable requires
    + adapt the tests to not expect the epoch
* Tue Jul 24 2018 tchvatal@suse.com
- Switch to multibuild layout
* Tue Jul 24 2018 tchvatal@suse.com
- Update to version 5.2.0+git20180620.70fa2258:
  * Rename the async kwarg in call_script to wait (reverses the logic)
  * Actually bump version to 5.3.0 snapshot
  * Bump version in VERSION file
  * [man] s/Pacakge/Package/g
  * Fix typos in README
  * Fix configure-base.sh after filesystem macro split
  * Split filesystem macros to separate macro file
  * Introduce javapackages-filesystem package
  * [java-functions] extend ABRT Java agent options
  * change abrt-java-connector upstream URL
  * Remove resolverSettings/prefixes from XMvn config
  * Add macros to allow passing arbitrary options to XMvn
  * [spec] Bump package version to 5.1.0
  * Allow specifying custom repo when calling xmvn-install
- Refresh patches:
  * suse-use-libdir.patch
  * python-optional.patch
* Mon Jan 22 2018 tchvatal@suse.com
- Update to version 5.0.0+git20180104.9367c8f6:
  * [java-functions] Avoid colons in jar names
  * Workaround for SCL enable scripts not working with -e
  * Second argument to pom_xpath_inject is mandatory
  * [mvn_artifact] Provide more helpful error messages
  * Fix traceback on corrupt zipfile
  * [test] Add reproducer for rhbz#1481005
  * [spec] Fix default JRE path
  * [readme] Fix typo
  * Add initial content to README.md (#21)
  * Decouple JAVA_HOME setting from java command alternatives
- Rebase patches:
  * python-optional.patch
  * suse-use-libdir.patch
- Drop merged patch fix-abs2rel.patch
* Wed May 24 2017 tchvatal@suse.com
- Fix typo in suse-use-libdir.patch
* Fri May 19 2017 tchvatal@suse.com
- Fix url to correct one https://github.com/fedora-java/javapackages
* Thu May 18 2017 tchvatal@suse.com
- Split to python and non-python edition for smaller depgraph
- Add patch python-optional.patch
- Fix abs2rel shebang:
  * fix-abs2rel.patch
- Fix Requires on subpackages to point to javapackages-tools proper
* Thu May 18 2017 tchvatal@suse.com
- Update to version 4.7.0+git20170331.ef4057e7:
  * Reimplement abs2rel in Python
  * Don't expand {scl} in macro definitions
  * Install expanded rpmfc attr files
  * [spec] Avoid file conflicts between in SCL
  * Fix macros.d directory ownership
  * Make %%ant macro enable SCL when needed
  * [spec] Fix file conflicts between SCL and non-SCL packages
  * Fix ownership of ivyxmldir
  * [test] Force locale for python processes
  * Don't include timestamp in generated pom.properties
- Remove patch merged by upstream:
  * create_valid_xml_comments.patch
- Remove patch suse-macros-install-location.patch
  * We switch to /usr/lib/ location for macros
- Try to reduce some dependencies bsc#1036025
- Refresh patch suse-use-libdir.patch
* Fri Feb 12 2016 toddrme2178@gmail.com
- Add create_valid_xml_comments.patch
  python-lxml 3.5.0 introduces validation for xml comments, and
  one of the comments created in this package were not valid.
  This patch fixes the problem.  It backported from upstream and
  should be in the next release.
  https://github.com/mizdebsk/javapackages/commit/84211c0ee761e93ee507f5d37e9fc80ec377e89d
* Mon Feb  8 2016 tchvatal@suse.com
- Version update to 4.6.0:
  * various bugfixes for maven tooling
  * introduction to gradle-local package for gradle packaging
* Wed Apr  1 2015 tchvatal@suse.com
- Drop dependency over source-highlight as it causes build cycle
* Tue Mar 31 2015 tchvatal@suse.com
- Try to break buildcycle detected on Factory
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build on SLE11
* Tue Mar 17 2015 tchvatal@suse.com
- Use python-devel instead of pkgconfig to build on sle11
* Tue Mar 17 2015 tchvatal@suse.com
- Add python-javapackages as requirement for main package
* Tue Mar 17 2015 tchvatal@suse.com
- Update requires on python packages to properly have all the needed
  dependencies on runtime
* Tue Mar 17 2015 tchvatal@suse.com
- Install macros to /etc/rpm as we do in SUSE:
  * suse-macros-install-location.patch
- Cleanup with spec-cleaner
* Fri Jan 23 2015 mailaender@opensuse.org
- Drop patches
  * depgen.patch
  * javapackages-2.0.1-fix-bashisms.patch
  * javapackages-2.0.1-java9.patch
  * maven_depmap-no-attribute-exit.patch
- Remove hacky workarounds
- Fix rpmlint errors
- Enable maven-local
- Avoid unsatisfiable dependencies
- Enable unit tests
- Update to version 4.4.0
* Mon Dec  8 2014 fstrba@suse.com
- Added patch:
  * javapackages-2.0.1-java9.patch: create directories for java,
    so that ant build works
- Add virtual provide jpackage-utils-java9 to be able to
  distinguish the presence of java9 compatibility
* Thu Oct 16 2014 ledest@gmail.com
- fix bashisms
- Added patches:
  * javapackages-2.0.1-fix-bashisms.patch
* Mon Mar 10 2014 darin@darins.net
- maven_depmap-no-attribute-exit.patch: SLES patch for ZipFile
  having no attribute '__exit__' which was causing ecj build
  failures
* Thu Mar  6 2014 darin@darins.net
- set correct libxslt package when building for SLES
* Fri Nov  8 2013 aj@ajaissle.de
- BuildRequires xz
- Remove '/etc/java' and '/usr/share/java' from file list (both owned by system)
- Url changed
* Wed Sep 11 2013 schwab@suse.de
- depgen.patch: drain stdin in dependency generator
* Wed Aug 21 2013 mvyskocil@suse.com
- update to 2.0.1
  * Fix creation of artifact aliases, resolves: rhbz#988462
- Update to upstream version 2.0.0
  * Merge functionality of jpackage-utils
  * Provide and obsolete jpackage-utils
  * %%%%add_maven_depmap macro now injects pom.properties to every JAR
  * %%%%add_to_maven_depmap and %%%%update_maven_depmap macros were removed
  * maven2jpp-mapdeps.xsl template has been removed
  * Macros related to installation of icons and desktop files were removed
  * 14 new manual pages were added
  * Documentation specific to JPackage was removed
  * Add BuildRequires: asciidoc, xmlto
  * Add lua to Requires
  * Add python-xml to Requires for xml.dom.minidom
* Fri Jul 12 2013 mvyskocil@suse.com
- make maven-local package build optional to not add unsatisfied
  dependencies to Factory
* Tue Jul  2 2013 mvyskocil@suse.com
- Create javapackages-tools 0.15.0 from fc20
  * Added depmap for tools.jar
  * Added support for versioned autorequires
  * New plugin metadata from Maven Central
  * move to independent package from jpackage-utils
